@@ -17,6 +17,9 @@
 #include "phosh-marshalers.h"
 #include "util.h"
 
+#define GNOME_DESKTOP_USE_UNSTABLE_API
+#include <libgnome-desktop/gnome-systemd.h>
+
 #include <gtk/gtk.h>
 #include <gio/gio.h>
 #include <gio/gdesktopappinfo.h>
@@ -90,6 +93,7 @@ struct _PhoshAppTracker {
   guint            idle_id;
   struct phosh_private_startup_tracker *wl_tracker; /* PhoshPrivate wayland interface */
   GHashTable      *apps;
+  GCancellable    *cancel;
 };
 G_DEFINE_TYPE (PhoshAppTracker, phosh_app_tracker, G_TYPE_OBJECT)
 
@@ -302,6 +306,23 @@ on_app_launch_started (PhoshAppTracker   *self,
 }
 
 
+static void
+on_start_systemd_scope_done (GObject *source_object, GAsyncResult *res, gpointer user_data)
+{
+  gboolean success;
+  g_autoptr (GError) err = NULL;
+  g_autofree char * app_id = user_data;
+
+  success = gnome_start_systemd_scope_finish (res, &err);
+  if (!success) {
+    g_warning ("Failed move '%s' to transient systemd unit: %s", app_id, err->message);
+    return;
+  }
+
+  g_warning ("Moved '%s' to transient systemd unit", app_id);
+}
+
+
 static void
 on_app_launched (PhoshAppTracker   *self,
                  GDesktopAppInfo   *info,
@@ -309,22 +330,24 @@ on_app_launched (PhoshAppTracker   *self,
                  GAppLaunchContext *context)
 {
   g_autofree gchar *startup_id = NULL;
+  const char *app_id;
   PhoshAppState *state;
   gint32 pid;
 
   g_return_if_fail (G_IS_DESKTOP_APP_INFO (info));
 
+  /* Launched via spawn */
+  g_variant_lookup (platform_data, "startup-notification-id", "s", &startup_id);
+  g_variant_lookup (platform_data, "pid", "i", &pid);
+  app_id = g_app_info_get_id (G_APP_INFO (info));
+
   /* Application doesn't handle startup notifications */
   if (!g_desktop_app_info_get_boolean (info, "StartupNotify"))
     goto out;
 
-  /* Launched via spawn */
-  g_variant_lookup (platform_data, "startup-notification-id", "s", &startup_id);
-  g_variant_lookup (platform_data, "pid", "i", &pid);
-
   /* No startup_id for e.g. Qt apps */
   if (!startup_id) {
-    g_debug ("No startup_id for %s", g_app_info_get_id (G_APP_INFO (info)));
+    g_debug ("No startup_id for %s", app_id);
     goto out;
   }
 
@@ -341,6 +364,16 @@ on_app_launched (PhoshAppTracker   *self,
                  info,
                  state->startup_id);
  out:
+  if (pid && app_id) {
+    gnome_start_systemd_scope (app_id,
+                               pid,
+                               "Application launched by phosh",
+                               self->session_bus,
+                               self->cancel,
+                               on_start_systemd_scope_done,
+                               g_strdup (app_id));
+  }
+
   g_object_unref (context);
 }
 
@@ -477,7 +510,7 @@ static gboolean
 on_idle (PhoshAppTracker *self)
 {
   g_bus_get (G_BUS_TYPE_SESSION,
-             NULL,
+             self->cancel,
              (GAsyncReadyCallback)on_bus_get_finished,
              self);
 
@@ -491,6 +524,9 @@ phosh_app_tracker_finalize (GObject *object)
 {
   PhoshAppTracker *self = PHOSH_APP_TRACKER (object);
 
+  g_cancellable_cancel (self->cancel);
+  g_clear_object (&self->cancel);
+
   g_clear_pointer (&self->apps, g_hash_table_destroy);
   g_clear_pointer (&self->wl_tracker, phosh_private_startup_tracker_destroy);
 
@@ -621,6 +657,7 @@ phosh_app_tracker_init (PhoshAppTracker *self)
   struct phosh_private *phosh_private = phosh_wayland_get_phosh_private (wl);
   uint32_t version;
 
+  self->cancel = g_cancellable_new ();
   self->apps = g_hash_table_new_full (g_str_hash,
                                       g_str_equal,
                                       g_free,
