@@ -69,7 +69,7 @@ on_shutdown_signal (gpointer unused)
 }
 
 
-static void
+G_NORETURN static void
 print_version (void)
 {
   printf ("Phosh %s - A Wayland shell for mobile devices\n", PHOSH_VERSION);
@@ -90,17 +90,17 @@ on_shell_ready (PhoshShell *shell, GTimer *timer)
 }
 
 
-int main(int argc, char *argv[])
+int
+main (int argc, char *argv[])
 {
-  g_autoptr(GOptionContext) opt_context = NULL;
-  GError *err = NULL;
+  g_autoptr (GOptionContext) opt_context = NULL;
+  g_autoptr (GError) err = NULL;
   gboolean unlocked = FALSE, locked = FALSE, version = FALSE;
-  g_autoptr(PhoshWayland) wl = NULL;
-  g_autoptr(PhoshShell) shell = NULL;
+  g_autoptr (PhoshWayland) wl = NULL;
+  g_autoptr (PhoshShell) shell = NULL;
   g_autoptr (PhoshBackgroundCache) background_cache = NULL;
   g_autoptr (GTimer) timer = g_timer_new ();
   g_autoptr (PhoshWallClock) wall_clock = phosh_wall_clock_new ();
-
   const GOptionEntry options [] = {
     {"unlocked", 'U', 0, G_OPTION_ARG_NONE, &unlocked,
      "Don't start with screen locked", NULL},
@@ -116,15 +116,13 @@ int main(int argc, char *argv[])
   g_option_context_add_group (opt_context, gtk_get_option_group (FALSE));
   if (!g_option_context_parse (opt_context, &argc, &argv, &err)) {
     g_warning ("%s", err->message);
-    g_clear_error (&err);
     return 1;
   }
 
-  if (version) {
+  if (version)
     print_version ();
-  }
 
-  phosh_log_set_log_domains (g_getenv("G_MESSAGES_DEBUG"));
+  phosh_log_set_log_domains (g_getenv ("G_MESSAGES_DEBUG"));
 
   textdomain (GETTEXT_PACKAGE);
   bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
@@ -140,11 +138,12 @@ int main(int argc, char *argv[])
   phosh_wall_clock_set_default (wall_clock);
   wl = phosh_wayland_get_default ();
   background_cache = phosh_background_cache_get_default ();
-  shell = phosh_shell_get_default ();
+  shell = phosh_shell_new ();
+  phosh_shell_set_default (shell);
 
   g_signal_connect (shell, "ready", G_CALLBACK (on_shell_ready), timer);
 
-  if (!(unlocked || phosh_shell_started_by_display_manager(shell)) || locked)
+  if (!(unlocked || phosh_shell_started_by_display_manager (shell)) || locked)
     phosh_shell_lock (shell);
 
   gtk_main ();
