@@ -88,9 +88,10 @@
 #include "wwan-info.h"
 #include "wwan/phosh-wwan-ofono.h"
 #include "wwan/phosh-wwan-mm.h"
-#include "wwan/phosh-wwan-backend.h"
 #include "wall-clock.h"
 
+#include "phosh-settings-enums.h"
+
 #define WWAN_BACKEND_KEY "wwan-backend"
 
 /**
@@ -195,13 +196,6 @@ typedef struct
   GSettings      *settings;
 } PhoshShellPrivate;
 
-
-typedef struct _PhoshShell
-{
-  GObject parent;
-} PhoshShell;
-
-
 static void phosh_shell_action_group_iface_init (GActionGroupInterface *iface);
 static void phosh_shell_action_map_iface_init (GActionMapInterface *iface);
 
@@ -1166,6 +1160,13 @@ static void phosh_shell_action_map_iface_init (GActionMapInterface *iface)
   iface->remove_action = phosh_shell_remove_action;
 }
 
+
+static GType
+get_lockscreen_type (PhoshShell *self)
+{
+  return PHOSH_TYPE_LOCKSCREEN;
+}
+
 /* }}} */
 /* {{{ GObject init */
 
@@ -1180,6 +1181,8 @@ phosh_shell_class_init (PhoshShellClass *klass)
   object_class->set_property = phosh_shell_set_property;
   object_class->get_property = phosh_shell_get_property;
 
+  klass->get_lockscreen_type = get_lockscreen_type;
+
   type_setup ();
 
   /**
@@ -1281,6 +1284,12 @@ phosh_shell_init (PhoshShell *self)
 
 /* }}} */
 
+PhoshShell *
+phosh_shell_new (void)
+{
+  return g_object_new (PHOSH_TYPE_SHELL, NULL);
+}
+
 static gboolean
 select_fallback_monitor (gpointer data)
 {
@@ -2056,6 +2065,25 @@ phosh_shell_get_area (PhoshShell *self, int *width, int *height)
     *height = h + PHOSH_TOP_BAR_HEIGHT + PHOSH_HOME_BAR_HEIGHT;
 }
 
+static PhoshShell *instance;
+
+/**
+ * phosh_shell_set_default:
+ * @self: The shell to use
+ *
+ * Set the PhoshShell singleton that is returned by `phosh_shell_get_default()`
+ */
+void
+phosh_shell_set_default (PhoshShell *self)
+{
+  g_return_if_fail (PHOSH_IS_SHELL (self));
+
+  g_clear_object (&instance);
+
+  instance = self;
+  g_object_add_weak_pointer (G_OBJECT (instance), (gpointer *)&instance);
+}
+
 /**
  * phosh_shell_get_default:
  *
@@ -2066,13 +2094,8 @@ phosh_shell_get_area (PhoshShell *self, int *width, int *height)
 PhoshShell *
 phosh_shell_get_default (void)
 {
-  static PhoshShell *instance;
-
-  if (instance == NULL) {
-    g_debug("Creating shell");
-    instance = g_object_new (PHOSH_TYPE_SHELL, NULL);
-    g_object_add_weak_pointer (G_OBJECT (instance), (gpointer *)&instance);
-  }
+  if (!instance)
+    g_error ("Shell singleton not set");
   return instance;
 }
 
@@ -2452,4 +2475,12 @@ phosh_shell_get_debug_flags (void)
   return debug_flags;
 }
 
+
+GType
+phosh_shell_get_lockscreen_type (PhoshShell *self)
+{
+  PhoshShellClass *klass = PHOSH_SHELL_GET_CLASS (self);
+  return klass->get_lockscreen_type (self);
+}
+
 /* }}} */
